@@ -6,6 +6,8 @@ set -uex
 
 TAG=$1
 
+PAWS_VERSION=0.44
+
 # provided.al2 lacks expat.
 yum install -y expat expat-devel
 cp /usr/lib64/libexpat.so.* /opt-lib/
@@ -21,7 +23,7 @@ esac
 
 cd /opt
 unzip "/var/task/.perl-layer/dist/perl-$TAG-runtime-al2-$ARCH.zip"
-/opt/bin/cpanm --notest --no-man-pages Paws@0.44
+/opt/bin/cpanm --notest --no-man-pages "Paws@$PAWS_VERSION"
 
 # remove pods
 find /opt/lib/perl5/site_perl -type f -a -name '*.pod' -delete
